aboutsummaryrefslogtreecommitdiffstats
path: root/libdevcore/SwarmHash.h
diff options
context:
space:
mode:
Diffstat (limited to 'libdevcore/SwarmHash.h')
-rw-r--r--libdevcore/SwarmHash.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/libdevcore/SwarmHash.h b/libdevcore/SwarmHash.h
index a5da96f5..a06f7bda 100644
--- a/libdevcore/SwarmHash.h
+++ b/libdevcore/SwarmHash.h
@@ -26,7 +26,7 @@
namespace dev
{
-/// Compute the "swarm hash" of @a _data
-h256 swarmHash(std::string const& _data);
+/// Compute the "swarm hash" of @a _input
+h256 swarmHash(std::string const& _input);
}